
## @knitr , echo=FALSE
suppressPackageStartupMessages(library(VariantAnnotation))
suppressPackageStartupMessages(library(AnnotationHub))


## @knitr 
hub <- AnnotationHub()
vcf <- hub$dbSNP.organisms.human_9606.VCF.ByChromosome.22.12159.GIH.RData 
dim(vcf)


## @knitr , echo=FALSE
suppressPackageStartupMessages(library(TxDb.Hsapiens.UCSC.hg19.knownGene))


## @knitr 
txdb_hg19 <- TxDb.Hsapiens.UCSC.hg19.knownGene
head(seqlevels(txdb_hg19))
seqlevels(vcf)
seqlevels(vcf) <- paste0("chr", seqlevels(vcf))
unique(genome(txdb_hg19))
genome(vcf) <- "hg19"


## @knitr 
intersect(seqlevels(txdb_hg19), seqlevels(vcf))


## @knitr 
gr_hg19 <- rowData(vcf)


## @knitr 
library(TxDb.Mmusculus.UCSC.mm10.ensGene)
txdb_mm10 <- TxDb.Mmusculus.UCSC.mm10.ensGene


## @knitr 
head(seqlevels(txdb_mm10))
gr_mm10 <- GRanges("chr4", IRanges(c(4000000, 107889000), width=1000))


## @knitr 
unique(genome(txdb_mm10))
genome(gr_mm10) <- "mm10"


## @knitr 
loc_hg19 <- locateVariants(gr_hg19, txdb_hg19, AllVariants())
table(loc_hg19$LOCATION)
loc_mm10 <- locateVariants(gr_mm10, txdb_mm10, AllVariants()) 
table(loc_mm10$LOCATION)


## @knitr , echo=FALSE
suppressPackageStartupMessages(library(org.Hs.eg.db))


## @knitr 
cols <- c("UNIPROT", "PFAM")
keys <- unique(loc_hg19$GENEID)
head(select(org.Hs.eg.db, keys, cols, keytype="ENTREZID"))


## @knitr , echo=FALSE
suppressPackageStartupMessages(library(org.Mm.eg.db))


## @knitr 
keys <- unique(loc_mm10$GENEID)
head(select(org.Mm.eg.db, keys, cols, keytype="ENSEMBL"))


## @knitr 
hub <- AnnotationHub()
filters(hub) <- list(Species = "Homo sapiens")
hg19_files <- names(hub)[grepl("hg19", names(hub))]
length(hg19_files)


## @knitr , echo=FALSE
ov_hg19 <- lapply(hg19_files[1:3], 
             function(x) 
               subsetByOverlaps(hub[[x]], gr_hg19))


## @knitr 
names(ov_hg19) <- hg19_files[1:3]
lapply(ov_hg19, head, n=3)


## @knitr , echo=FALSE
suppressPackageStartupMessages(library(BSgenome.Hsapiens.UCSC.hg19))


## @knitr 
head(predictCoding(vcf, txdb_hg19, Hsapiens), 3)


## @knitr , echo=FALSE
suppressPackageStartupMessages(library(ensemblVEP))


## @knitr 
library(ensemblVEP)
fl <- system.file("extdata", "ex2.vcf", 
                  package="VariantAnnotation")


## @knitr , echo=FALSE
gr <- ensemblVEP(fl)


## @knitr 
head(gr, 3)


