
## @knitr echo=FALSE
suppressPackageStartupMessages(library(hgu95av2.db))


## @knitr 
## Affymetrix U133 2.0 array IDs of interest; these might be
## obtained from
##
##   tbl <- topTable(efit, coef=2)
##   ids <- tbl[["ID"]]
##
## as part of a more extensive workflow.
ids <- c("39730_at", "1635_at", "1674_at", "40504_at", "40202_at")


## @knitr 
library("hgu95av2.db")


## @knitr 
cols(hgu95av2.db)


## @knitr 
keytypes(hgu95av2.db)


## @knitr 
head(keys(hgu95av2.db, keytype="ENTREZID"))


## @knitr 
select(hgu95av2.db, keys=ids, cols="ENTREZID", keytype="PROBEID")


## @knitr 
select(hgu95av2.db, keys=ids, cols=c("ENTREZID","GENENAME", "SYMBOL"), keytype="PROBEID")


## @knitr 
res <- select(hgu95av2.db, keys=ids[1], cols="GO", keytype="PROBEID")
head(res)


## @knitr 
library("GO.db")
head(res$GO)  ## shows what we are using as keys
head(select(GO.db, keys=res$GO, cols="TERM", keytype="GOID"))


## @knitr 
library(org.Hs.eg.db)
keys <- head(keys(org.Hs.eg.db, keytype="ENTREZID"), n=2)
cols <- c("PFAM","GO", "SYMBOL")
select(org.Hs.eg.db, keys, cols, keytype="ENTREZID")


## @knitr echo=FALSE
suppressPackageStartupMessages(library(TxDb.Hsapiens.UCSC.hg19.knownGene))


## @knitr 
library(TxDb.Hsapiens.UCSC.hg19.knownGene)
txdb <- TxDb.Hsapiens.UCSC.hg19.knownGene ## done for convenience
keys <- head(keys(txdb, keytype="GENEID"), n=2)
cols <- c("TXNAME", "TXSTART","TXSTRAND")
select(txdb, keys, cols, keytype="GENEID")


## @knitr 
transcripts(txdb)


## @knitr 
exons(txdb)


## @knitr 
transcripts(txdb, columns = c("tx_id","tx_name","gene_id"))


## @knitr 
transcriptsBy(txdb, by="gene")


## @knitr echo=FALSE
suppressPackageStartupMessages(library(Homo.sapiens))


## @knitr 
library(Homo.sapiens)
keys <- head(keys(Homo.sapiens, keytype="ENTREZID"), n=2)
cols <- c("SYMBOL","TXNAME")
select(Homo.sapiens, keys, cols, keytype="ENTREZID")


## @knitr 
transcripts(Homo.sapiens, columns=c("TXNAME","SYMBOL"))


## @knitr eval=FALSE
## gd <- list(join1 = c(GO.db="GOID", org.Hs.eg.db="GO"),
##       	   join2 = c(org.Hs.eg.db="ENTREZID",
##            TxDb.Hsapiens.UCSC.hg19.knownGene="GENEID"))
## 
## makeOrganismPackage(pkgname = "Homo.sapiens",
## 	            graphData = gd,
## 		    organism = "Homo sapiens",
## 		    version = "1.0.0",
## 		    maintainer = "Package Maintainer<maintainer@somewhere.org>",
## 		    author = "Some Body",
## 		    destDir = ".",
## 		    license = "Artistic-2.0")


## @knitr 
library(AnnotationHub)

ah = AnnotationHub()


## @knitr 
res <- ah$goldenpath.hg19.encodeDCC.wgEncodeUwTfbs.wgEncodeUwTfbsMcf7CtcfStdPkRep1.narrowPeak_0.0.1.RData

res


## @knitr 
length(ah)


## @knitr 
filters(ah)


## @knitr 
cols(ah)


## @knitr 
head(keys(ah, keytype="Species"))


## @knitr 
filters(ah) <- list(Species="Bos taurus")

length(ah)


## @knitr 
library("biomaRt")
head(listMarts())
ensembl <- useMart("ensembl")
ensembl


## @knitr 
head(listDatasets(ensembl))
ensembl <- useMart("ensembl",dataset="hsapiens_gene_ensembl")
ensembl


## @knitr 
head(listFilters(ensembl))


## @knitr 
head(listAttributes(ensembl))


## @knitr 
affyids=c("202763_at","209310_s_at","207500_at")
getBM(attributes=c('affy_hg_u133_plus_2', 'entrezgene'), 
                    filters = 'affy_hg_u133_plus_2', 
                    values = affyids, mart = ensembl)


## @knitr 
head(getBM(attributes='affy_hg_u133_plus_2', mart = ensembl))


## @knitr eval=FALSE
## source("http://bioconductor.org/biocLite.R")
## biocLite(c("hgu95av2.db", "GO.db"))


## @knitr eval=FALSE
## library(AnnotationDbi)
## library(GO.db)


## @knitr eval=FALSE
## browseVignettes(package="AnnotationDbi")


## @knitr eval=FALSE
## help.start()


## @knitr 
keys <- "MSX2"
cols <- c("ENTREZID","PROBEID", "CHR")
select(hgu95av2.db, keys, cols, keytype="SYMBOL")


## @knitr 
chipSymbols <- keys(hgu95av2.db, keytype="SYMBOL")
orgSymbols <- keys(org.Hs.eg.db, keytype="SYMBOL")
length(orgSymbols)
length(chipSymbols)


## @knitr 
dim(select(org.Hs.eg.db,orgSymbols, "ENTREZID", "SYMBOL"))
dim(select(hgu95av2.db,chipSymbols, "ENTREZID", "SYMBOL")) 


## @knitr 
length(cols(org.Hs.eg.db)) < length(cols(hgu95av2.db))


## @knitr 
head(select(hgu95av2.db,chipSymbols, "PROBEID", "SYMBOL"))


## @knitr 
egr <- select(org.Hs.eg.db, orgSymbols, "ENTREZID", "SYMBOL")
length(egr$ENTREZID)
length(unique(egr$ENTREZID))
## VS:
length(egr$SYMBOL)
length(unique(egr$SYMBOL))
## So lets trap these symbols that are redundant and look more closely...
redund <- egr$SYMBOL
badSymbols <- redund[duplicated(redund)]
select(org.Hs.eg.db, badSymbols, "ENTREZID", "SYMBOL")


## @knitr 
res1 <- select(TxDb.Hsapiens.UCSC.hg19.knownGene, 
               keys(TxDb.Hsapiens.UCSC.hg19.knownGene, keytype="TXID"),
       	       cols=c("GENEID","TXNAME","TXCHROM"), keytype="TXID")

head(res1)


## @knitr 
res2 <- transcripts(TxDb.Hsapiens.UCSC.hg19.knownGene, 
                    columns = c("gene_id","tx_name")) 
head(res2)


## @knitr 
library(TxDb.Athaliana.BioMart.plantsmart16)
res <- transcripts(TxDb.Athaliana.BioMart.plantsmart16, columns = c("gene_id")) 


## @knitr eval=FALSE
## library(Homo.sapiens)
## keys <- keys(Homo.sapiens, keytype="TXID")
## res1 <- select(Homo.sapiens,
##                keys= keys,
##        	       cols=c("SYMBOL","TXSTART","TXCHROM"), keytype="TXID")
## 
## head(res1)


## @knitr 
library(Homo.sapiens)
res2 <- transcripts(Homo.sapiens, columns="SYMBOL") 
head(res2)


## @knitr 
cols(Homo.sapiens)
cols(org.Hs.eg.db)
cols(TxDb.Hsapiens.UCSC.hg19.knownGene)
## You might also want to look at this:
transcripts(Homo.sapiens, columns=c("SYMBOL","CHRLOC"))


## @knitr 
keytypes(ah)


## @knitr 
keys(ah, keytype="DataProvider")
head(keys(ah, keytype="Genome"))


## @knitr 
filters(ah) <- NULL
filters(ah) <- list(Species="Homo sapiens", 
                    DataProvider="hgdownload.cse.ucsc.edu",
		    Genome="hg19")
length(ah)


## @knitr 
res <- ah$goldenpath.hg19.database.oreganno_0.0.1.RData


## @knitr 
library("biomaRt")
ensembl <- useMart("ensembl",dataset="hsapiens_gene_ensembl")
ids=c("1")
getBM(attributes=c('go_id', 'entrezgene'), 
		    filters = 'entrezgene',
                    values = ids, mart = ensembl)



## @knitr 
library(org.Hs.eg.db)
ids=c("1")
select(org.Hs.eg.db, keys=ids, cols="GO", keytype="ENTREZID")


## @knitr 
sessionInfo()


